# Text-Based Prompt Engineering

!!! warning "Under Construction"

    This section is currently under construction. We are actively working on finalizing the material for publish.

When prompting an LLM, you can often improve the quality of results just by making slight changes to the prompt itself. Text-based prompt engineering techniques are far more useful for older and less powerful models, which are finnicky and prone to errors. That being said, they still have their place in the newest generation of LLMs, and for some examples we've identified scenarios in which they still show improvements.
